Connection

Struct Connection 

pub struct Connection {
    pub id: String,
    pub receiver: SplitSink<WebSocket, Message>,
}
type for each individual connection.

Fields

id: Stringreceiver: SplitSink<WebSocket, Message>

Implementations

Source

impl Connection

pub fn create(id: String, receiver: SplitSink<WebSocket, Message>) -> Self

create a connection:

pub async fn send(&mut self, message: Utf8Bytes) -> Result<(), Error>

pub async fn send_if<F>(&mut self, message: Utf8Bytes, condition: F)
where F: Fn(&Connection) -> bool,

send the text message if the given condition in it’s closure is true.

pub async fn send_if_not<F>(&mut self, message: Utf8Bytes, condition: F)
where F: Fn(&Connection) -> bool,

sen the text message if the given condition in it’s closure is true.

pub async fn ping(&mut self, message: Bytes) -> Result<(), Error>

send the ping.

pub async fn ping_if<F>(&mut self, message: Bytes, condition: F)
where F: Fn(&Connection) -> bool,

send the ping if the given condition in it’s closure is true.

pub async fn ping_if_not<F>(&mut self, message: Bytes, condition: F)
where F: Fn(&Connection) -> bool,

sen the ping if the given condition in it’s closure is true.

pub async fn pong(&mut self, message: Bytes) -> Result<(), Error>

send the pong.

pub async fn pong_if<F>(&mut self, message: Bytes, condition: F)
where F: Fn(&Connection) -> bool,

send the pong if the given condition in it’s closure is true.

pub async fn pong_if_not<F>(&mut self, message: Bytes, condition: F)
where F: Fn(&Connection) -> bool,

sen the pong if the given condition in it’s closure is true.